*****************
Example Notebooks
*****************

`HPMCM` comes with several notebooks that demonstrate how to use it to analyze data in a number of different ways.

Here we describe the various notebooks and suggest other ways in which you might study the data.


===================
Checking input data
===================

.. toctree::
   :maxdepth: 2
   :caption: Comparing signal-to-noise of input catalogs

   examples/CompareSN.ipynb


.. toctree::
   :maxdepth: 2
   :caption: Comparing sky-coverage of input catalogs

   examples/CompareSkyCoverage.ipynb

   
=======================================
Matching catalogs using a specified WCS
=======================================

.. toctree::
   :maxdepth: 2
   :caption: Matching Metadetect no-shear catalog to object catalog using WCS

   examples/CompareToObjectTable.ipynb

   
.. toctree::
   :maxdepth: 2
   :caption: Estimating match efficiecy between metadetect no-shear catalog and object catalog

   examples/MatchEffic.ipynb

   
=======================
Matching shear catalogs
=======================
   
.. toctree::
   :maxdepth: 2
   :caption: Matching shear catalogs using cell-based coadd coordinates

   examples/CompareCatTypes.ipynb

  
.. toctree::
   :maxdepth: 2
   :caption: Estimating match efficiecy between shear catalgos 

   examples/ShearMatchEffic.ipynb


=================
Shear calibration
=================
   
.. toctree::
   :maxdepth: 2
   :caption: Reading shear match data directly

   examples/ShearData.ipynb

   
.. toctree::
   :maxdepth: 2
   :caption: High-level meta analysis of shear calibration

   examples/Meta.ipynb

   
.. toctree::
   :maxdepth: 2
   :caption: Deeper dive in to matching shear catalogs

   examples/CellBased.ipynb

   
